/**
*	Workaround extension for the header view
*	which takes all the space when "all headers" is activated
*
*   Preferences:
*   mail.headerScroll.maxheight - Maximum height the "all headers" view may take. Default is 200
*
*	@author Christian Weiske <cweiske@cweiske.de>
*/
var headerScroll = {
	maxheight: 200,
	bFirst: true,
	enablingElements: new Array(
	   "viewallheaders", "mnenhyViewAllHeaders"
	),
	disablingElements: new Array(
	   "viewnormalheaders", "mnenhyViewNoHeaders", "mnenhyViewNormalHeaders",
	   "urn:mnenhy:header:custom0"
	),


	/**
	*  tries to read a preference setting and to return it
	*  falls back to the given default if the preference doesn't exist
	*/
	getPref: function(strName, nDefault)
	{
	   var value;
	   try {
	       value = pref.getIntPref(strName);
	   } catch (exception) {
	       value = nDefault;
	   }
	   return value;
	},//getPref: function(strName, nDefault)



	enableScrolling: function()
	{
		dump("headerScroll: enableScrolling\r\n");
		document.getElementById('msgHeaderView').setAttribute("maxheight",headerScroll.getPref("mail.headerScroll.maxheight", headerScroll.maxheight));
		//FIXME: don't overwrite but append style
        document.getElementById('msgHeaderView').setAttribute("style","overflow:auto;");
	},

	disableScrolling: function()
	{
		dump("headerScroll: disableScrolling\r\n");
		//or "removeAttribute"?
        document.getElementById('msgHeaderView').removeAttribute("maxheight");
        //FIXME: don't overwrite but append style
		//perhaps set overflow:none?
        document.getElementById('msgHeaderView').setAttribute("style","");
	},



    MsgViewAllHeaders: function()
    {
        headerScroll.enableScrolling();
        headerScroll.RealMsgViewAllHeaders();
    },

    MsgViewNormalHeaders: function()
    {
        headerScroll.disableScrolling();
        headerScroll.RealMsgViewNormalHeaders();
    },



    /**
    *   Sets up the event listener for headerScroll
    *   We do that to get notified when a message
    *   has been selected
    */
    setupEventListener: function()
    {
dump("headerScroll: setup\n");
        //why is it loaded twice?
        if (!headerScroll.bFirst) { return; }
        headerScroll.bFirst = false;
dump("headerScroll: setup2\n");

        // Grab functions that require us to update
        headerScroll.RealMsgViewAllHeaders = window.MsgViewAllHeaders;
        window.MsgViewAllHeaders = headerScroll.MsgViewAllHeaders;

        headerScroll.RealMsgViewNormalHeaders = window.MsgViewNormalHeaders;
        window.MsgViewNormalHeaders = headerScroll.MsgViewNormalHeaders;

        //This and the above notification is needed. Maybe it's double work most times,
        //but the toggle button extension won't work with us if we don't do both
        for (arrayid in headerScroll.enablingElements) {
            var mnuViewAllHeader = document.getElementById(headerScroll.enablingElements[arrayid]);
            if (mnuViewAllHeader) {
                mnuViewAllHeader.setAttribute(
                    "oncommand",
                    "headerScroll.enableScrolling();" + mnuViewAllHeader.getAttribute("oncommand")
                );
            }
        }
        for (arrayid in headerScroll.disablingElements) {
            var mnuViewNormalHeader = document.getElementById(headerScroll.disablingElements[arrayid]);
            if (mnuViewNormalHeader) {
                mnuViewNormalHeader.setAttribute(
                    "oncommand",
                    "headerScroll.disableScrolling();" + mnuViewNormalHeader.getAttribute("oncommand")
                );
            }
        }

        //user_pref("mail.show_headers", 2); -> all headers activated at startup
        if (
            (gPrefBranch.getIntPref("mail.show_headers") == 2)
        ) {
            //2 at startup means that all headers view is enabled!
            headerScroll.enableScrolling();
        }

//        dump("headerScroll: setupEventListener\r\n");
    }//setupEventListener: function()

}//var headerScroll

addEventListener('messagepane-loaded', headerScroll.setupEventListener, true);
